
# THIS FILE IS GENERATED FROM wofry SETUP.PY
short_version = '1.0.10'
version = '1.0.10'
full_version = '1.0.10'
git_revision = 'c6e13b67804b30535e6a998d7b5d7dfb7d3bdb23'
release = True

if not release:
    version = full_version
    short_version += ".dev"
